# Part of the project "How culture shapes choices related to fertility and mortality: causal evidence at the Swiss language border" 
# by Lisa Faessler, Rafael Lalive, Charles Efferson
# Evolutionary Human Sciences, 2024

# RDD analysis for data from referanda
# Lisa Faessler, 2023

# Create RDD graphs


setwd("~/Desktop")
windowWidth <- 6
windowHeight <- 4

# install packages for RDD
library(Matrix)
library(lfe)
library(rdrobust)

# and for tables
library(dplyr)


# referenda vectors
votes_list <- c(20130922,20140209,20140928,20160605,20200927,20210613)   # yearMonthDay of each referenda


for (i in 1:length(votes_list)) {

  ### import datasets
  
  # datasets with voting behaviors and distances
  df <- read.csv(paste("vot_",votes_list[i],"_dist.csv",sep = "")) 
  df <- subset(df, df$dist_km<=100) # restrict sample to 100km around the border
  
  bilingual <- c(10,23,2) # vector with the bilingual cantons (Fribourg, Wallis, Bern)
  
  # create a dummy with municipality type urban/ rural, instead of city, suburban, rural
  df$urban <- NA
  df$urban[df$city==1 | df$suburb==1] <- 1
  df$urban[df$rural==1] <- 0
  
  # create a variable with the proportion of yes votes (instead of the number of yes)
  df$prop <- NA 
  df$prop[] <- df$Oui[]/(df$Oui[]+df$Non[]) # proportion of yes
  df$prop <- df$prop*100


  ### RDD graphs
  
  # create a graph for each referenda in the referenda vector
  pdf(width = windowWidth, height = windowHeight, file =  paste("vot_",df$vot_code[1],"_graph.pdf", sep = ""))
  
  # linear estimator
  rdplot(df$prop, df$dist_border, 
         covs = df$kant, # control for cantons
         p = 1, # polynomial order 1 for the lines (linear estimator)
         nbins = c(200, 200), binselect = "qsmv", # quantile-spaced bins 
         #h = 80,                                # bandwith size, no bandwidth, sample already restricted to 100km
         y.lim = c(0.0, 100), x.lim = c(-100, 100),
         masspoints = "off",
         col.lines = "red", col.dots = "steelblue4", 
         title = "",
         x.label = "distance to language border (km)", y.label = "% yes votes")
  
  dev.off()
}
