# Part of the project "How culture shapes choices related to fertility and mortality: causal evidence at the Swiss language border" 
# by Lisa Faessler, Rafael Lalive, Charles Efferson
# Evolutionary Human Sciences, 2024


# RDD analysis for data from referanda
# Lisa Faessler, 2024

# Regressions analyses


setwd("~/Desktop")
windowWidth <- 6
windowHeight <- 4

# install packages for RDD
library(Matrix)
library(lfe)

# and for tables
library(stargazer)


# referenda vectors
votes_list <- c(20130922,20140209,20140928,20160605,20200927,20210613)

for (i in 1:length(votes_list)) {
  
  ### import datasets
  
  df <- read.csv(paste("vot_",votes_list[i],"_dist.csv",sep = ""))   # for each referenda, voting results and distance
  df_controls <- read.csv("municipalities_controls.csv")   # additional data (controls) about municipalities 

  df <- merge(df,df_controls,by="gdenr")  # gdenr = unique identifier number for municipalities
  rm(df_controls)
  df <- subset(df, df$dist_km<=100) # restrict sample to 100km around the border
  
  
  # create a dummy with municipality type urban/ rural, instead of city, suburban, rural
  df$urban <- NA
  df$urban[df$city==1 | df$suburb==1] <- 1
  df$urban[df$rural==1] <- 0
  
  # create a variable with the proportion of yes votes (instead of the number of yes)
  df$prop <- NA 
  df$prop[] <- df$Oui[]/(df$Oui[]+df$Non[]) # proportion of yes

  

  ### RDD estimation
  
  # regressions
  
  # m1 - no control
  m1 <- lm(prop ~ german*dist_border, data=df)
  
  # m2 - cantons fixed effects
  m2 <- lm(prop ~ german*dist_border + as.factor(kant), data=df)
  
  # m3 - canton FE + municipality type (urban/ rural)
  m3 <- lm(prop ~ german*dist_border + as.factor(kant) + as.factor(urban), data=df)
  
  # m4 - canton FE + municipality type (urban/ rural) + municipality level controls
  # controls include: proportion of population below 19, proportion of population above 65, young dependency ratio
  # size of the household, birth rate, average revenue, tax rates
  m4 <- lm(prop ~ german*dist_border + as.factor(kant) + as.factor(urban)
           + age19 + age65 + depJeunes + householdSize + nat + revenueTaxPerson + taxFam80 + taxSingle80,
           data=df)


  ## regression tables

  
  # html format 
  stargazer(m1, m2, m3, m4,
            covariate.labels = c("German Language","German*Distance","Distance","Urban", "Constant"),
            type = "html",
            order = c("german","dist_border","german:dist_border","as.factor(urban)1"),
            intercept.top=FALSE,
            intercept.bottom=TRUE,
            omit = c("kant", "age19", "age65", "depJeunes", "householdSize", "nat", "revenueTaxPerson", "taxFam80", "taxSingle80"),
            star.char = c("+", "*", "**", "***"),
            star.cutoffs = c(.1, .05, .01, .001),
            title = paste("votation: ",df$vot_code[i],sep = ""),
            out=paste("table_",df$vot_code[i],".html",sep = "") )
  
  # latex format
  stargazer(m1, m2, m3, m4,
            #covariate.labels = c("German Language","German*Distance","Distance","Urban", "Constant"),
            type = "latex",
            order = c("german","dist_border","german:dist_border","urban1"),
            intercept.top=FALSE,
            intercept.bottom=TRUE,
            omit = c("kant", "age19", "age65", "depJeunes", "householdSize", "nat", "revenueTaxPerson", "taxFam80", "taxSingle80"),
            star.char = c("+", "*", "**", "***"),
            star.cutoffs = c(0.1, 0.05, 0.01, 0.001),
            title = paste("votation: ",df$vot_code[i],sep = ""),
            out=paste("table_",df$vot_code[i],".tex",sep = "") )

}